print_table

Function print_table 

pub fn print_table<W: Write>(
    out: &mut W,
    headers: &[&str],
    rows: &[Vec<String>],
) -> Result<()>
Print rows as a simple aligned table.

Column widths are computed from the headers plus all cell contents. Columns are separated by a two-space gutter, and a separator line of dashes is printed between the header row and the data rows.