Module set

Module set 

set / get / unset subcommand handlers.

Currently the only supported key is default, which selects the browser to use when BROWSER_CONTROL is unset and no positional argument is given.

Enums

Key

Functions

run_get
browser-control get <key> [--json].
run_set
browser-control set <key> <value>. With no value, returns an error pointing at unset.
run_unset
browser-control unset <key>.