pub fn is_bidi_target_gone(code: &str, message: &str) -> boolExpand description
Returns true if code or message indicates a BiDi context is gone.
BiDi codes are stable per spec (no such frame, etc.), but we also
scan the message in case the code is generic.