Module foreground

Module foreground 

foreground_holders SQLite table: one row per tab whose foreground emulation is currently held by a browser-control tab foreground-hold process (see crate::session::foreground). Rows whose pid is dead are evicted lazily on read, like bidi_locks.

Structs

ForegroundRow
In-memory view of a foreground_holders row.