open_backend

Function open_backend 

pub async fn open_backend(endpoint: &str, engine: Engine) -> Result<TabBackend>
Open the right TabBackend for a resolved browser endpoint, taking care of BiDi’s session.new handshake. The returned backend is Clone and owns its underlying client via Arc.